# nav.myt - Provides page navigation elements that are derived from toc.TOCElement structures, including # individual hyperlinks as well as navigational toolbars and table-of-content listings. <%namespace name="tocns" file="toc.html"/> <%def name="itemlink(item, paged, extension, anchor=True)" filter="trim"> ${ item.description } <%def name="toclink(toc, path, extension, paged, description=None)" filter="trim"> <% item = toc.get_by_path(path) if description is None: if item: description = item.description else: description = path if item: anchor = not paged or item.depth > 1 else: anchor = False %> % if item: ${ description } % else: ${ description } % endif <%def name="link()" filter="trim(href, text, class_)"> ${ text } <%def name="topnav(item, toc, extension, paged)">
<%def name="pagenav(item, paged, extension)">
% if item.previous is not None: Previous: ${itemlink(item=item.previous, paged=paged, anchor=not paged, extension=extension)} % endif % if item.next is not None: ${item.previous is not None and "|" or ""} Next: ${itemlink(item=item.next, paged=paged, anchor=not paged, extension=extension)} % endif

### Table of Contents